Gratiot: Leatherback nest counts from Gratiot et al. (2006) Figure 1
Description
Leatherback nest counts from Gratiot et al. (2006) Figure
1. These data have been collected by the ONG Kwata in
French Guiana.
The data have been obtained from the
graph of the publication (see reference).
Usage
Gratiot
Arguments
format
data.frame with the morning date in the first column and the nest counts on the second one.
Details
Leatherback nest counts from Gratiot et al. (2006) Figure 1
References
Gratiot, N., Gratiot, J., de Thoisy, B. & Kelle, L. 2006.
Estimation of marine turtles nesting season from incomplete
data ; statistical adjustment of a sinusoidal function.
Animal Conservation, 9, 95-102.
library(phenology)
# Read a file with dataGratiot<-read.delim("http://max2.ese.u-psud.fr/epc/conservation/BI/Complete.txt", header=FALSE)
data(Gratiot)