Learn R Programming

phenology (version 5.1)

likelihood_phenology: Estimate the likelihood of timeseries based on a set of parameters.

Description

This function is used to estimate the likelihood based on a set of parameters.

Usage

likelihood_phenology(data = NULL, parametersfit = NULL, parametersfixed = NULL, zero_counts = NULL, method_incertitude = NULL, result = NULL)

Arguments

data
Dataset generated with add_format
parametersfit
Set of parameters to be fitted
parametersfixed
Set of fixed parameters
zero_counts
example c(TRUE, TRUE, FALSE) indicates whether the zeros have been recorder for each of these timeseries. Defaut is TRUE for all.
method_incertitude
2 [default] is the correct one from a statistical point of view; 0 is an aproximate method more rapid; 1 is an alternative more rapid but biased.
result
An object obtained after fit_phenology()

Value

The likelihood of the data with the parameters

Details

likelihood_phenology estimate likelihood for a set of parameters.

Examples

Run this code
## Not run: 
# # Read a file with data
# Gratiot<-read.delim("http://max2.ese.u-psud.fr/epc/conservation/BI/Complete.txt", header=FALSE)
# data(Gratiot)
# # Generate a formated list nammed data_Gratiot 
# data_Gratiot<-add_phenology(Gratiot, name="Complete", 
# 		reference=as.Date("2001-01-01"), format="%d/%m/%Y")
# # Generate initial points for the optimisation
# parg<-par_init(data_Gratiot, parametersfixed=NULL)
# # Estimate likelihood with this initial set of parameters
# likelihood_phenology(data=data_Gratiot, parametersfit=parg, parametersfixed=NULL)
# # Or directly from a result object
# likelihood_phenology(result=result_Gratiot)
# ## End(Not run)

Run the code above in your browser using DataLab